Development: [![Development status](https://circleci.com/gh/sensu/sensu-go-ansible/tree/master.svg?style=shield)](https://app.circleci.com/pipelines/github/sensu/sensu-go-ansible?branch=master) |
Stable: [![Stable status](https://circleci.com/gh/sensu/sensu-go-ansible/tree/stable.svg?style=shield)](https://app.circleci.com/pipelines/github/sensu/sensu-go-ansible?branch=stable)


# Sensu Go Ansible Collection

Sensu Go Ansible Collection is a bundle of Ansible content that we can use to
manage all aspects of Sensu Go. It contains Ansible roles for installing and
configuring backends and agents. Collection also contains a wide selection of
modules for runtime management of Sensu Go backend.

Collection is freely available on [Ansible Galaxy][galaxy]. For Red Hat
subscribers, this collection is also available on [Automation Hub][hub].

   [galaxy]: https://galaxy.ansible.com/sensu/sensu_go
             (Sensu Go on Ansible Galaxy)
   [hub]: https://cloud.redhat.com/ansible/automation-hub/sensu/sensu_go
          (Sensu Go on Automation Hub)

For user guides and references, please visit [the documentation site][docs].
And if you would like to help us out, check our [hacking docs][hacking].

   [docs]: https://sensu.github.io/sensu-go-ansible/
           (Sensu Go Ansible Collection documentation)
   [hacking]: https://sensu.github.io/sensu-go-ansible/hacking.html
              (Developer guides)
